==> jc-1.4.0.tar.gz: polyglot/main/Main__24TerminationException.h <==
// public class polyglot.main.Main$TerminationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 90ca25b9a2e84f1b polyglot_main_Main__24TerminationException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_polyglot_main_Main__24TerminationException_H_
#define _JC_polyglot_main_Main__24TerminationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_main_Main__24TerminationException$sub_refs	_jc_polyglot_main_Main__24TerminationException$sub_refs;
typedef struct _jc_polyglot_main_Main__24TerminationException$sub_nonrefs	_jc_polyglot_main_Main__24TerminationException$sub_nonrefs;
typedef struct _jc_polyglot_main_Main__24TerminationException$refs	_jc_polyglot_main_Main__24TerminationException$refs;
typedef struct _jc_polyglot_main_Main__24TerminationException$nonrefs	_jc_polyglot_main_Main__24TerminationException$nonrefs;
typedef struct _jc_polyglot_main_Main__24TerminationException$object	_jc_polyglot_main_Main__24TerminationException$object;

typedef const struct _jc_polyglot_main_Main__24TerminationException$vmethods	_jc_polyglot_main_Main__24TerminationException$vmethods;
typedef const struct _jc_polyglot_main_Main__24TerminationException$vtable	_jc_polyglot_main_Main__24TerminationException$vtable;
typedef const struct _jc_polyglot_main_Main__24TerminationException$vtype	_jc_polyglot_main_Main__24TerminationException$vtype;

// Constructors
extern void _jc_polyglot_main_Main__24TerminationException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_polyglot_main_Main__24TerminationException$object *, jint);
extern void _jc_polyglot_main_Main__24TerminationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_main_Main__24TerminationException$object *, struct _jc_java_lang_String$object *);
extern void _jc_polyglot_main_Main__24TerminationException$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_polyglot_main_Main__24TerminationException$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods structure
struct _jc_polyglot_main_Main__24TerminationException$vmethods {
};

// Vtable
struct _jc_polyglot_main_Main__24TerminationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_polyglot_main_Main__24TerminationException$vmethods	polyglot_main_Main__24TerminationException;
};

// Vtype
struct _jc_polyglot_main_Main__24TerminationException$vtype {
	_jc_type			type;
	_jc_polyglot_main_Main__24TerminationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_main_Main__24TerminationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_main_Main__24TerminationException$refs {
    _jc_polyglot_main_Main__24TerminationException$sub_refs	polyglot_main_Main__24TerminationException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_main_Main__24TerminationException$sub_nonrefs {
	jint	exitCode;
};

// Non-reference instance fields (object)
struct _jc_polyglot_main_Main__24TerminationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_polyglot_main_Main__24TerminationException$sub_nonrefs	polyglot_main_Main__24TerminationException;
};

// Object instance structure
struct _jc_polyglot_main_Main__24TerminationException$object {
	_jc_polyglot_main_Main__24TerminationException$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_main_Main__24TerminationException$vtype	*vtype;
	_jc_polyglot_main_Main__24TerminationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_main_Main__24TerminationException$vtype _jc_polyglot_main_Main__24TerminationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_main_Main__24TerminationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_main_Main__24TerminationException$class_object;

#endif	/* _JC_polyglot_main_Main__24TerminationException_H_ */

==> jc-1.4.6.tar.gz: polyglot/main/Main__24TerminationException.h <==
// public class polyglot.main.Main$TerminationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 90ca25b9a2e84f1b polyglot_main_Main__24TerminationException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_polyglot_main_Main__24TerminationException_H_
#define _JC_polyglot_main_Main__24TerminationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_main_Main__24TerminationException$sub_refs	_jc_polyglot_main_Main__24TerminationException$sub_refs;
typedef struct _jc_polyglot_main_Main__24TerminationException$sub_nonrefs	_jc_polyglot_main_Main__24TerminationException$sub_nonrefs;
typedef struct _jc_polyglot_main_Main__24TerminationException$refs	_jc_polyglot_main_Main__24TerminationException$refs;
typedef struct _jc_polyglot_main_Main__24TerminationException$nonrefs	_jc_polyglot_main_Main__24TerminationException$nonrefs;
typedef struct _jc_polyglot_main_Main__24TerminationException$object	_jc_polyglot_main_Main__24TerminationException$object;

typedef const struct _jc_polyglot_main_Main__24TerminationException$vmethods	_jc_polyglot_main_Main__24TerminationException$vmethods;
typedef const struct _jc_polyglot_main_Main__24TerminationException$vtable	_jc_polyglot_main_Main__24TerminationException$vtable;
typedef const struct _jc_polyglot_main_Main__24TerminationException$vtype	_jc_polyglot_main_Main__24TerminationException$vtype;

// Constructors
extern void _jc_polyglot_main_Main__24TerminationException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_polyglot_main_Main__24TerminationException$object *, jint) _JC_JCNI_ATTR;
extern void _jc_polyglot_main_Main__24TerminationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_main_Main__24TerminationException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_main_Main__24TerminationException$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_polyglot_main_Main__24TerminationException$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_main_Main__24TerminationException$vmethods {
};

// Vtable
struct _jc_polyglot_main_Main__24TerminationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_polyglot_main_Main__24TerminationException$vmethods	polyglot_main_Main__24TerminationException;
};

// Vtype
struct _jc_polyglot_main_Main__24TerminationException$vtype {
	_jc_type			type;
	_jc_polyglot_main_Main__24TerminationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_main_Main__24TerminationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_main_Main__24TerminationException$refs {
    _jc_polyglot_main_Main__24TerminationException$sub_refs	polyglot_main_Main__24TerminationException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_main_Main__24TerminationException$sub_nonrefs {
	jint	exitCode;
};

// Non-reference instance fields (object)
struct _jc_polyglot_main_Main__24TerminationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_polyglot_main_Main__24TerminationException$sub_nonrefs	polyglot_main_Main__24TerminationException;
};

// Object instance structure
struct _jc_polyglot_main_Main__24TerminationException$object {
	_jc_polyglot_main_Main__24TerminationException$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_main_Main__24TerminationException$vtype	*vtype;
	_jc_polyglot_main_Main__24TerminationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_main_Main__24TerminationException$vtype _jc_polyglot_main_Main__24TerminationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_main_Main__24TerminationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_main_Main__24TerminationException$class_object;

#endif	/* _JC_polyglot_main_Main__24TerminationException_H_ */
